##
# .release.distutils - distutils data
##
"""
Python distutils data provisions module.

For sub-packagers, the `prefixed_packages` and `prefixed_extensions` functions
should be of particular interest.
"""
import sys
import os
import distutils.core
from ..project import version, name, identity as url

LONG_DESCRIPTION = """
"""

CLASSIFIERS = [
	'Development Status :: 3 - Alpha',
	#'Development Status :: 5 - Production/Stable',
	'Intended Audience :: Developers',
	'Environment :: Console',
	'License :: Public Domain',
	'License :: Freely Distributable',
	'License :: Freeware',
	'Natural Language :: English',
	'Operating System :: OS Independent',
	'Programming Language :: Python',
	'Programming Language :: Python :: 3',
	'Topic :: Software Development :: Libraries',
	'Topic :: Software Development :: Build Tools',
	'Topic :: Software Development :: Debuggers',
	'Topic :: Software Development :: Testing',
	'Topic :: System :: Shells',
	'Topic :: System :: Software Distribution',
	'Topic :: Utilities',
]

subpackages = [
	'test',
	'documentation',
	'release',
]

extensions_data = {
	'lib' : {
		'sources' : [],
	},
}

package_data = {
	'documentation' : ['*.txt'],
	None : ['*.c'],
}

try:
	# :)
	if __package__ is not None:
		default_prefix = __package__.split('.')[:-1]
	else:
		default_prefix = __name__.split('.')[:-2]
except NameError:
	default_prefix = ['dev']

def prefixed_extensions(
	prefix = default_prefix,
	extensions_data = extensions_data,
):
	"""
	Generator producing the `distutils` `Extension` objects.
	"""
	pkg_prefix = '.'.join(prefix) + '.'
	path_prefix = os.path.sep.join(prefix)
	for mod, data in extensions_data.items():
		yield distutils.core.Extension(
			pkg_prefix + mod,
			[os.path.join(path_prefix, src) for src in data['sources']],
			libraries = data.get('libraries', ()),
		)

def prefixed_packages(
	prefix = default_prefix,
	packages = subpackages,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	yield prefix
	prefix = prefix + '.'
	for pkg in packages:
		yield prefix + pkg

def prefixed_package_data(
	prefix = default_prefix,
	package_data = package_data,
):
	"""
	Generator producing the standard `package` list prefixed with `prefix`.
	"""
	prefix = '.'.join(prefix)
	for pkg, data in package_data.items():
		if pkg is None:
			yield prefix, data
		else:
			yield prefix + '.' + pkg, data

def standard_setup_keywords(build_extensions = True, prefix = default_prefix):
	return {
		'name' : name,
		'version' : version,
		'description' : '',
		'long_description' : LONG_DESCRIPTION,
		'author' : 'James William Pye',
		'author_email' : 'x@jwp.name',
		'maintainer' : 'James William Pye',
		'maintainer_email' : 'x@jwp.name',
		'url' : url,
		'classifiers' : CLASSIFIERS,
		'packages' : list(prefixed_packages(prefix = prefix)),
		'package_data' : dict(prefixed_package_data(prefix = prefix)),
		'cmdclass' : dict(test=TestCommand),
		#'ext_modules' : list(prefixed_extensions(prefix = prefix)),
	}

class TestCommand(distutils.core.Command):
	description = "run tests"

	# List of option tuples: long name, short name (None if no short
	# name), and help string.
	user_options = []

	def initialize_options(self):
		pass

	def finalize_options(self):
		pass

	def run(self):
		import unittest
		unittest.main(module='dev.test.testall', argv=('setup.py',))
